.. See LICENSE for details

Repo Manager's documentation!
==========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   contributing
   authors

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
